/*
* CLIF is a Load Injection Framework
* Copyright (C) 2004 France Telecom R&D
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*
* CLIF 
*
* Contact: clif@objectweb.org
*/
package org.objectweb.clif.isac.plugins.httpmatrix10.tools;

/**
 * This class is a matrix description
 * 
 * @author JC Meillaud
 * @author A Peyrard
 */
public class MatrixDescription {
	private double[][] matrix ;
	private String[] urls ;
	private double[] waiting_times ;
	private int[] nbHitBeforeEnding ;
	private int size ;
	
	/**
	 * Construtor, build a new matrix description
	 * The matrix is a square matrix
	 * @param number Size of the matrix
	 */
	public MatrixDescription(int number) {
		// init all the tables
		this.matrix = new double[number][number] ;
		this.urls = new String[number] ;
		this.waiting_times = new double[number] ;
		this.nbHitBeforeEnding = new int[number] ;
		// init the size
		this.size = number ;
	}
	
	/**
	 * Set the cell Aij in the matrix
	 * @param i The X-axis value of the cell
	 * @param j The Y-axis value of the cell
	 * @param value of the cell
	 * @return true if the sell has been set, else false
	 */
	public boolean setCell(int i, int j, double value) {
		// check if the coord are right
		if (i <= size && j <= size) {
			// set the value
			matrix[i][j] = value ;
			return true ;
		}
		else 
			// the cell was not found
			return false ;
	}
	
	/**
	 * Get the cell value Aij
	 * @param i The X-axis value of the cell
	 * @param j The Y-axis value of the cell
	 * @return The cell value
	 */
	public double getCell(int i, int j) {
		// check if the coord are right
		if (i <= size && j <= size) {
			// get the value
			return matrix[i][j] ;
		}
		else
			return -1 ;
	}

	/**
	 * Set an url
	 * @param n The number of the url to be set
	 * @param url The url to be set
	 * @return True if the url has been set
	 */
	public boolean setUrl(int n, String url) {
		if (n <= size) {
			urls[n] = new String(url) ;
			return true ;
		}
		else 
			return false ;
	}
	
	/**
	 * Get an url
	 * @param n The number of the url
	 * @return The url 
	 */
	public String getUrl(int n) {
		if (n <= size) {
			return urls[n] ;
		}
		else
			return null ;
	}
	
	/**
	 * Set a waiting time
	 * @param n The number of the waiting time to be set
	 * @param time The waiting time to be set
	 * @return True if the waiting time has been set
	 */
	public boolean setWaitingTime(int n, double waiting_time) {
		if (n <= size) {
			waiting_times[n] = waiting_time ;
			return true ;
		}
		else 
			return false ;
	}
	
	/**
	 * Get a waiting time
	 * @param n The number of the waiting time
	 * @return The waiting time
	 */
	public double getWaitingTime(int n) {
		if (n <= size) {
			return waiting_times[n] ;
		}
		else
			return -1 ;
	}
	
	/**
	 * Set a value of the ending table, 0 means what the link is not a ending link
	 * @param n the number of the link
	 * @param nbB the number of hit to this link before ending
	 * @return True if the number have been set
	 */
	public boolean setNbHitBeforeEnding(int n, int nbB) {
		if (n<=size) {
			nbHitBeforeEnding[n] = nbB ;
			return true;
		}
		return false ;
	}
	
	/**
	 * Get a value of the ending table
	 * @param n the number of the link
	 * @return The number of hits before ending for this link
	 */
	public int getNbHitBeforeEnding(int n) {
		if (n<=size) {
			return nbHitBeforeEnding[n];
		}
		return -1;
	}
	
	/**
	 * @return Returns the size.
	 */
	public int getSize() {
		return size;
	}
	
	/**
	 * @param size The size to set.
	 */
	public void setSize(int size) {
		this.size = size;
	}
	
	/**
	 * Implementation of the method toString
	 * used in the debug of the class
	 */
	public String toString() {
		String result = "** Matrix Description : \n" ;
		result = result.concat("-size=" + this.size + "\n") ;
		for (int i=0;i<this.size;i++) {
			result = result.concat("url"+i+"="+this.urls[i]+"\n") ;
			result = result.concat("  waiting_time=" + waiting_times[i]+"\n") ;
		}
		for (int i=0;i<this.size;i++) {
			for (int j=0;j<this.size;j++) {
				result = result.concat(this.matrix[i][j]+" ") ;
			}
			result = result.concat("\n") ;
		}
		return result ;
	}
}